@@ -13,12 +13,12 @@
 ##############################################################################
 """Templated Resource Processor
 
-$Id: replace.py 82068 2007-12-01 04:57:45Z fafhrd $
+$Id: replace.py 101277 2009-06-25 17:07:41Z icemac $
 """
 __docformat__='restructuredtext'
 import re
 import zope.interface
-from zope.app.pagetemplate import engine
+from zope.pagetemplate import engine
 from z3c.zrtresource import interfaces
 
 # <EXPR-TYPE>"<INPUT-EXPR>" <EXPR-TYPE>"<OUTPUT-EXPR>" <NUM>
