@@ -13,12 +13,14 @@
 ##############################################################################
 """CSS Resource
 
-$Id: zrtresource.py 101277 2009-06-25 17:07:41Z icemac $
+$Id: zrtresource.py 103303 2009-08-27 16:21:04Z nadako $
 """
 __docformat__='restructuredtext'
+from zope.browserresource.file import File, FileResource
+from zope.browserresource.interfaces import IResourceFactory
+from zope.browserresource.interfaces import IResourceFactoryFactory
+from zope.interface import implements, classProvides
 from zope.site.hooks import getSite
-from zope.app.publisher.fileresource import File
-from zope.app.publisher.browser.fileresource import FileResource
 
 from z3c.zrtresource import processor, replace
 
@@ -33,6 +35,9 @@ class ZRTFileResource(FileResource):
 
 
 class ZRTFileResourceFactory(object):
+    
+    implements(IResourceFactory)
+    classProvides(IResourceFactoryFactory)
 
     def __init__(self, path, checker, name):
         self.__file = File(path, name)
